@@ -55,6 +55,7 @@ static const GOptionEntry entries[] =
   { "device", 'd', 0, G_OPTION_ARG_STRING, &mount_device_file, N_("Mount volume with device file"), NULL},
   { "unmount", 'u', 0, G_OPTION_ARG_NONE, &mount_unmount, N_("Unmount"), NULL},
   { "unmount-scheme", 's', 0, G_OPTION_ARG_STRING, &unmount_scheme, N_("Unmount all mounts with the given scheme"), NULL},
+  /* Translator: List here is a verb as in 'List all mounts' */
   { "list", 'l', 0, G_OPTION_ARG_NONE, &mount_list, N_("List"), NULL},
   { "detail", 'i', 0, G_OPTION_ARG_NONE, &extra_detail, N_("Show extra information for List and Monitor"), NULL},
   { "monitor", 'o', 0, G_OPTION_ARG_NONE, &mount_monitor, N_("Monitor events"), NULL},
@@ -359,7 +360,7 @@ list_mounts (GList *mounts,
   GMount *mount;
   GVolume *volume;
   char *name, *uuid, *uri;
-  GFile *root;
+  GFile *root, *default_location;
   GIcon *icon;
   char **x_content_types;
   char *type_name;
@@ -394,6 +395,15 @@ list_mounts (GList *mounts,
           if (uuid)
             g_print ("%*suuid=%s\n", indent + 2, "", uuid);
 
+          default_location = g_mount_get_default_location (mount);
+          if (default_location)
+            {
+              char *loc_uri = g_file_get_uri (default_location);
+              g_print ("%*sdefault_location=%s\n", indent + 2, "", loc_uri);
+              g_free (loc_uri);
+              g_object_unref (default_location);
+            }
+
           icon = g_mount_get_icon (mount);
           if (icon)
             {
